pub fn write_dimension_key(out: &mut Vec<u8>, dim: IndexDimension, value: &[u8])Expand description
Append a dimension key into out using the [tag_byte][value_bytes] format.
pub fn write_dimension_key(out: &mut Vec<u8>, dim: IndexDimension, value: &[u8])Append a dimension key into out using the [tag_byte][value_bytes] format.